pub struct BugRecords {
pub df_bugs: FxHashMap<usize, TyBug>,
pub df_bugs_unwind: FxHashMap<usize, TyBug>,
pub uaf_bugs: FxHashMap<usize, TyBug>,
pub dp_bugs: FxHashMap<usize, TyBug>,
pub dp_bugs_unwind: FxHashMap<usize, TyBug>,
}Fields
df_bugs: FxHashMap<usize, TyBug>df_bugs_unwind: FxHashMap<usize, TyBug>uaf_bugs: FxHashMap<usize, TyBug>dp_bugs: FxHashMap<usize, TyBug>dp_bugs_unwind: FxHashMap<usize, TyBug>Implementations
Sourceimpl BugRecords
impl BugRecords
pub fn new() -> BugRecords
Sourcepub fn try_merge_pair(
&mut self,
drop_spot: LocalSpot,
trigger_bb: usize,
in_type: BugType,
) -> Option<BugType>
pub fn try_merge_pair( &mut self, drop_spot: LocalSpot, trigger_bb: usize, in_type: BugType, ) -> Option<BugType>
Returns Some(bug_type) if the caller should insert the bug with the returned type.
Returns None if the bug should be skipped (already covered by an existing entry).
When both UAF and DF exist for the same pair, DF wins as the survivor.
pub fn is_bug_free(&self) -> bool
pub fn df_bugs_output<'tcx>( &self, body: &Body<'tcx>, fn_name: Symbol, span: Span, )
pub fn uaf_bugs_output<'tcx>( &self, body: &Body<'tcx>, fn_name: Symbol, span: Span, )
pub fn dp_bug_output<'tcx>( &self, body: &Body<'tcx>, fn_name: Symbol, span: Span, )
fn emit_bug_reports<'tcx, F>( &self, body: &Body<'tcx>, bugs: &FxHashMap<usize, TyBug>, fn_name: Symbol, span: Span, log_msg: &str, title: &str, detail_formatter: F, )